[PC-BSD Commits] r15058 - pcbsd/current/src-qt4/libpcbsd
svn at pcbsd.org
svn at pcbsd.org
Tue Jan 24 19:53:24 PST 2012
Author: kenmoore
Date: 2012-01-25 03:53:24 +0000 (Wed, 25 Jan 2012)
New Revision: 15058
Modified:
pcbsd/current/src-qt4/libpcbsd/hardware.cpp
pcbsd/current/src-qt4/libpcbsd/pcbsd-hardware.h
Log:
Fix a typo in libpcbsd hardware functionality - should be hcsecd referenced in the function name, not hcsecs
Modified: pcbsd/current/src-qt4/libpcbsd/hardware.cpp
===================================================================
--- pcbsd/current/src-qt4/libpcbsd/pcbsd-hardware.h 2012-01-25 03:45:07 UTC (rev 15057)
+++ pcbsd/current/src-qt4/libpcbsd/pcbsd-hardware.h 2012-01-25 03:53:24 UTC (rev 15058)
@@ -44,7 +44,7 @@
static QStringList readSavedBTDevice(QString bdaddr);
private:
- static QString getHcsecsDeviceValue(QString rawline); //for bluetooth functions
+ static QString getHcsecdDeviceValue(QString rawline); //for bluetooth functions
};
#endif
More information about the Commits
mailing list
--- pcbsd/current/src-qt4/libpcbsd/hardware.cpp 2012-01-25 03:45:07 UTC (rev 15057)
+++ pcbsd/current/src-qt4/libpcbsd/hardware.cpp 2012-01-25 03:53:24 UTC (rev 15058)
@@ -123,7 +123,7 @@
QString line = instream.readLine();
if( line.contains("device {") && !line.contains("#") ){
//grab the value for the bdaddr from the next line
- bdaddrList << getHcsecsDeviceValue( instream.readLine() );
+ bdaddrList << getHcsecdDeviceValue( instream.readLine() );
}
} //end of loop over file
filein.close();
@@ -143,13 +143,13 @@
QString line = instream.readLine();
if( line.contains("device {") && !line.contains("#") ){
//grab the value for the bdaddr from the next line
- QString bdaddrchk = getHcsecsDeviceValue( instream.readLine() );
+ QString bdaddrchk = getHcsecdDeviceValue( instream.readLine() );
if(bdaddrchk == bdaddr){//not entry to be removed
//save these device configurations
settings << bdaddrchk; //bdaddr
- settings << getHcsecsDeviceValue( instream.readLine() ); //name
- settings << getHcsecsDeviceValue( instream.readLine() ); //key
- settings << getHcsecsDeviceValue( instream.readLine() ); //pin
+ settings << getHcsecdDeviceValue( instream.readLine() ); //name
+ settings << getHcsecdDeviceValue( instream.readLine() ); //key
+ settings << getHcsecdDeviceValue( instream.readLine() ); //pin
break; //end the loop, data already found
}
}
@@ -169,13 +169,13 @@
QString line = instream.readLine();
if( line.contains("device {") && !line.contains("#") ){
//grab the value for the bdaddr from the next line
- QString bdaddrchk = getHcsecsDeviceValue( instream.readLine() );
+ QString bdaddrchk = getHcsecdDeviceValue( instream.readLine() );
if(bdaddrchk != bdaddr){//not entry to be removed
//save these device configurations
oldbdaddr << bdaddrchk;
- oldname << getHcsecsDeviceValue( instream.readLine() );
- oldkey << getHcsecsDeviceValue( instream.readLine() );
- oldpin << getHcsecsDeviceValue( instream.readLine() );
+ oldname << getHcsecdDeviceValue( instream.readLine() );
+ oldkey << getHcsecdDeviceValue( instream.readLine() );
+ oldpin << getHcsecdDeviceValue( instream.readLine() );
}
}
} //end of loop over file
@@ -209,8 +209,8 @@
if(willRestart) { restartBT(); }
}
-QString Hardware::getHcsecsDeviceValue(QString rawline){
- //returns the value of the variable on a given raw line from the hcsecs.conf file
+QString Hardware::getHcsecdDeviceValue(QString rawline){
+ //returns the value of the variable on a given raw line from the hcsecd.conf file
QString line = rawline.simplified().section(";",0,0); //remove the ";" at the end of the line
//qDebug() << line;
line = line.section(" ",1,1,QString::SectionSkipEmpty); //remove the label at the beginning
Modified: pcbsd/current/src-qt4/libpcbsd/pcbsd-hardware.h
===================================================================